@@ -2,7 +2,6 @@
 
 import logging
 import unittest
-from io import StringIO
 from click.testing import CliRunner
 from src.model_pipeline import model_pipe
 import src
@@ -17,7 +16,8 @@ class TestPipeline(unittest.TestCase):
     def test_click(self):
         """Should test click"""
         runner = CliRunner()
-        result = runner.invoke(model_pipe, ['--process-type=train', 'configs/logistic_regression_config.yaml'])
+        result = runner.invoke(model_pipe,
+                               ['--process-type=train', 'configs/logistic_regression_config.yaml'])
         assert result.exit_code == 0
 
 
